% Explicit solution of St. Venant equations combined with implicit solution
% of Green Ampts infiltration equation. Will compute one dimensional swale
% flow for rectangular and trapezoidal cross sections.
%
% Source St. Venant: 
% Numerical Modelling and Hydraulics, 3rd edition, 9. March 2013
% http://folk.ntnu.no/nilsol/tvm4155/flures6.pdf

clear all % fresh start
close all % no open windows

format long

%%%%%%%%%%%%%%%%%%%%%%%%% Input Channel Geometry%%%%%%%%%%%%%%%%%%%%%%%%%%%

prompt = 'Length of channel [m] = ';
length = input(prompt);

prompt = 'Lengthwise step [m] = ';
deltax = input(prompt);

prompt = 'Timestep [s] = ';
timestep = input(prompt);

prompt = 'Number of iterations = ';
%Plotting time = number of it. * timestep
numb_it = input(prompt)+1;

prompt = 'Channel lengthwise slope [x/1000] = ';
slope = input(prompt)/1000;

prompt = 'Mannings number [M] = ';      
manning = input(prompt);

prompt = ['Swale cross section shape \n'...
    '[1 = rectangular, 2 = trapezoidal] = '];
shape = input(prompt);

if shape == 1;
    
    prompt = 'Bottom width of channel [m] = ';
    B = input(prompt);

elseif shape == 2;
    
    prompt = 'Bottom width of channel [m] = ';
    B = input(prompt);

    prompt = 'Side slope [x:1] = ';         %Side slope angle
    z = input(prompt);
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%Soil charactheristics %%%%%%%%%%%%%%%%%%%%%%%%%%

prompt = 'Include infiltration step [Y=1/N=0] ?';
infiltration_step = input(prompt);

if infiltration_step == 1

prompt = ['Define soil characteristics from list \n \n \n sand = 1'...
    '\n loamy_sand = 2 \n sandy_loam = 3 \n loam = 4 \n silt_loam = 5'...
    '\n sandy_clay_loam = 6 \n \n = '];
soiltype = input(prompt);

%%%From Rawls et al 1982 "Estimation of soil water properties"%%%%%

if soiltype == 1
   
    K_sat = 21.00;              %Saturated hydraulic conductivity [cm/h]
    theta_sat = 0.437;          %Max volumetric saturation [cm^3/cm^3]
    psi = 7.26;                 %Suction pressure head [cm]
    
    prompt = 'Initial soil saturation (0.020-0.437 [cm^3/cm^3]) = ';
    theta_0 = input(prompt);
    
elseif soiltype == 2
    
    K_sat = 6.11;
    theta_sat = 0.437;
    psi = 8.69;
    
    prompt = 'Initial soil saturation (0.035-0.437 [cm^3/cm^3]) = ';
    theta_0 = input(prompt);
    
elseif soiltype == 3
    
    K_sat = 2.59;
    theta_sat = 0.453;
    psi = 14.66;
    
    prompt = 'Initial soil saturation (0.041-0.453 [cm^3/cm^3]) = ';
    theta_0 = input(prompt);
    
elseif soiltype == 4
    
    K_sat = 1.32;
    theta_sat = 0.463;
    psi = 11.15;
    
    prompt = 'Initial soil saturation (0.027-0.463 [cm^3/cm^3]) = ';
    theta_0 = input(prompt);
    
elseif soiltype == 5
    
    K_sat = 0.68;
    theta_sat = 0.501;
    psi = 20.76;
    
    prompt = 'Initial soil saturation (0.015-0.501 [cm^3/cm^3]) = ';
    theta_0 = input(prompt);
    
elseif soiltype == 6
    
    K_sat = 0.43;
    theta_sat = 0.398;
    psi = 28.08;
    
    prompt = 'Initial soil saturation (0.068-0.598 [m^3/m^3]) = ';
    theta_0 = input(prompt);
    
end

prompt = 'Drainage layer thickness [cm] = ';
z_tot = input(prompt);

prompt = 'Infiltration step solver. [1 = symbolic, 2 = numerical] = ';
solver = input(prompt);

gamma = atan(slope);                    % Longitudinal slope in degrees

end
            
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


sections = (length/deltax)+400;         %Added 400 for plot extension

disp('Working...')

% Reading time series from input hydrograph

in = load('inflow.txt');                
out_q = fopen('outflow.txt','w');           % Clean output files
fclose(out_q);
out_y = fopen('depth.txt','w');
fclose(out_y);
out_u = fopen('velocity.txt','w');
fclose(out_u);
out_inf = fopen('infiltration.txt','w');
fclose(out_inf);

timein = in(:,1);
qinn = in(:,2);
n = size(in,1);
m_temp = max(in,[],1);
m = max(m_temp);
tol_depth = 0.005;       %Dry cell limit, 5mm


%%%%%%%%%%%%%%%%%%%%%%%%%%% Initialization %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%% 1. Determine inflow u and y %%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%% Iteration loop rectangualar channel %%%%%%%%%%%%%%%%%%%%%%

if shape == 1,

    y_old = zeros(1,200);
    y_new = zeros(1,200);
   
        for i = 2:200              
            
        y_old(1) = 1;
    
        y_new(i-1) = qinn(1)/(manning*B*((B)/((B/y_old(i-1))+2))^(2/3)...
            *sqrt(slope));
    
        y_old(i) = y_new(i-1);
    
            if (abs(y_old(i)-y_old(i-1))) < 0.0001     
        
                y = y_old(i);
                
                if y < tol_depth
                    
                    y = tol_depth;
                        
                end
        
                break
        
            end
    
        end
        
    A = B*y;
    u = qinn(1)/A;
    R = A/(2*y+B);



%%%%%%%%%%%%%%%%%%% Iteration loop trapezoidal channel %%%%%%%%%%%%%%%%%%%%


elseif shape == 2,

    
    control_iter = zeros(1,1000);
    y_iter = zeros(1,1000);
            
    for i = 2:5000                  
                
                control = qinn(1)/(manning*sqrt(slope));
                
                y_iter(1) = 0;
                
                control_iter(i) = (B*y_iter(i-1)+z*(y_iter(i-1))^2)*...
                    ((B*y_iter(i-1)+z*(y_iter(i-1))^2)/...
                    (sqrt(B+z*y_iter(i-1)*(1+z^2))))^(2/3);
                
                if (abs(control-control_iter(i))) < 0.001  
                    
                    y = y_iter(i-1);
                    
                        if y < tol_depth;       %Dry cell limitation 
                        
                            y = tol_depth;
                        
                        end
                    
                    break
                    
                end
                
                y_iter(i) = y_iter(i-1)+0.001;  %Threshold accuracy 1mm
                
    end
    
    B_top = B+2*z*y;
    A = ((B+B_top)/(2))*y;
    u = qinn(1)/A;
    R = A/(B+2*sqrt(y^2+(z*y)^2));
    
end

depth(1:sections+1,1:2) = y;        %Vector preparation for St. Venants
velocity(1:sections+1,1:2) = u;

if shape == 1
   
    area_rect(1:sections+1,1:2) = A;
    R_hyd(1:sections+1,1:2) = R;

elseif shape == 2                   %Trapezoid area for discretization
    
    area_trap(1:sections+1,1:2) = A;
    B_t(1:sections+1,1:2) = B_top;
    R_hyd(1:sections+1,1:2) = R;
    
end

%%%%%%%%%%%%%%%%%%% Initialize infiltration step %%%%%%%%%%%%%%%%%%%%%%%%%%

if infiltration_step == 1           %Calculates infiltration depth in cm
    
    I = zeros(numb_it,1);           %Starting with no infiltration i,1
    I_diff = zeros(numb_it,1);
    I_vol = zeros(numb_it,1);
    inf_control = zeros(3000,1);
    inf_control_0 = zeros(3000,1);
    
    iter_inf_0 = zeros(3000,1); 
   
    inf_length = u*timestep;        %Initialize wetted length
    I_tot_vol = zeros(numb_it,1);
    
    if y > tol_depth 
        
        if solver == 1      %Implements MATLAB integrated symbolic solver.
                
            syms I_solver_0
            
            old = digits;
            
            digits(10);             %Solver accuracy
            
            I_0 = vpasolve(K_sat*(timestep/(60*60))*cos(gamma)...
                +((psi+y*100*cos(gamma))*(theta_sat-theta_0))...
                /(cos(gamma))*log(1+(I_solver_0*cos(gamma)/...
                ((psi+y*cos(gamma))*(theta_sat-theta_0))))==I_solver_0,...
                I_solver_0, K_sat*(timestep/(60*60))*cos(gamma));
            
            double(I_0);
            
            digits(old);
            
        elseif solver == 2          %Numerical solver based on iterations
            
        for l = 2:3000                        
        
        inf_control_0(1) = K_sat*(timestep/(60*60))*cos(gamma);
                
        inf = K_sat*(timestep/(60*60))*cos(gamma)...
            +((psi+y*100*cos(gamma))*(theta_sat-theta_0))...
            /(cos(gamma))*log(1+(inf_control_0(l-1)*cos(gamma)/...
            ((psi+y*cos(gamma))*(theta_sat-theta_0))));
        
            if abs(inf-inf_control_0(l-1)) < 0.01   
                    
            I_0 = inf_control_0(l-1);
                    
            break
                    
            else
                    
            inf_control_0(l) = inf_control_0(l-1)+0.01;
                    
            end
        
        end
        
        end
    end
    
    if (y*100) > tol_depth
        
        I(1) = I_0;     %Initial intfiltration set equal for all cells
        
    
    else              
        
        I(1) = 0;   
      
    end

end
    

%%%%%%%%%%%%%%%%%%%%%%%%%% Check for instabilities %%%%%%%%%%%%%%%%%%%%%%%%

Cr = (abs(u)+sqrt(9.81*y))/(deltax/timestep); 

if Cr > 1
    
disp('Courant number exceeded! Check input parameters, reduce timestep');
    
    break    
end

%%%%%%%%%%%%%%%%%%%%% 2. Repeat for each time step %%%%%%%%%%%%%%%%%%%%%%%%







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%                               Main loop

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%







time = timein(1);           

for j=1:numb_it 
    
    % Boundary inflow conditions
    
    for k=1:n-1                     
        if (timein(k)>time)
            break;
        end
        beta = (timein(k+1)-time)/(timein(k+1)-timein(k));
        
        q = qinn(k)*beta+qinn(k+1)*(1-beta);
        
%%%%%%%%%%%%%%%%%%% Iteration loop rectangualar channel %%%%%%%%%%%%%%%%%%%

        if shape == 1,

        y_old = zeros(1,200);
        y_new = zeros(1,200);
   
        for i = 2:200                % Internal iteration for normal depth
            
            y_old(1) = 1;
    
            y_new(i-1) = q/(manning*B*((B)/((B/y_old(i-1))+2))^(2/3)*...
                sqrt(slope));
    
            y_old(i) = y_new(i-1);
    
                if (abs(y_old(i)-y_old(i-1))) < 0.0001
        
                    y = y_old(i);
                    
                    if y < tol_depth    %Dry cell control
                    
                        y = tol_depth;          
                    
                    end
                    
                    break
        
                end
    
        end
    
        A = B*y;
        u = q/A;
        R = A/(2*y+B);
        

%%%%%%%%%%%%%%%%%% Iteration loop trapezoidal channel %%%%%%%%%%%%%%%%%%%%%


        elseif shape == 2

            control_iter = zeros(1,1000);
            y_iter = zeros(1,1000);
            
        for i = 2:5000                  %Internal iteration normal depth
                
        control = q/(manning*sqrt(slope));
                
        y_iter(1) = 0;
                
        control_iter(i) = (B*y_iter(i-1)+z*(y_iter(i-1))^2)*...
            ((B*y_iter(i-1)+z*(y_iter(i-1))^2)/(sqrt(B+z*y_iter(i-1)...
            *(1+z^2))))^(2/3);
                
                if (abs(control-control_iter(i))) < 0.001
                    
                    y = y_iter(i-1);
                    
                    if y < tol_depth    %Dry cell limitation
                        
                        y = tol_depth;
                        
                    end
                    
                    break
                    
                end
                
                y_iter(i) = y_iter(i-1)+0.001;  %Threshold accuracy 1mm
                
        end 
            
        B_top = B+2*z*y;
        A = ((B+B_top)/(2))*y;
        u = q/A;
        R = A/(B+2*sqrt(y^2+(z*y)^2));

        end
        

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	
        velocity(1,1) = u;      %Preparing vectors for St. Venants
        velocity(1,2) = u;
        depth(1,1) = y;
        depth(1,2) = y;
        R_hyd(1,1) = R;
        R_hyd(1,2) = R;
       
    	velocity(sections,1) = velocity(sections-1,2);
        depth(sections,1) = depth(sections-1,2);
        R_hyd(sections,1) = R_hyd(sections-1,2);
        
        if shape == 2           %Parameters for trapezoidal discretization
            
            B_t(1,1) = B_top;
            B_t(1,2) = B_top;
            B_t(sections,1) = B_t(sections-1,2);
            
            area_trap(1,1) = A;
            area_trap(1,2) = A;
            area_trap(sections,1) = area_trap(sections-1,2);
   
        end
        
    end
    
%%%%%%%%%%%%%%%%%% Water depth according to Eq. (5.10) %%%%%%%%%%%%%%%%%%%%
    
    for i=2:sections
        
        if shape == 1,
            
            
    
            depth(i,2) = depth(i,1)-timestep/(2.0*deltax)*(velocity(i,1)*...
            (depth(i+1,1)-depth(i-1,1))+depth(i,1)*...
            (velocity(i+1,1)-velocity(i-1,1)));
        
            R_hyd(i,2) = (B*depth(i,2))/(2*depth(i,2)+B);
        
            if depth(i,2) < tol_depth           %Dry cell control
                
                depth(i,2) = tol_depth;
                
            end
        
        end
        
        if shape == 2,      
            
        depth(i,2) = depth(i,1)-((2*timestep)/(B+B_t(i,1)))*...
            (velocity(i,1))*(((B+B_t(i,1))/2)*((depth(i+1,1)+...
            depth(i-1,1))/(2*deltax))*((B+B_t(i,1))/(2))*depth(i,1)*...
            ((velocity(i+1,1)+velocity(i-1,1))/(2*deltax)));
        
        if depth(i,2) < tol_depth           %Dry cell control
            
            depth(i,2) = tol_depth;
            
        end
        
        B_t(i,2) = B+2*z*depth(i,2);
        area_trap(i,2) = ((B+B_t(i,2))/2)*depth(i,2);  
        R_hyd(i,2) = area_trap(i,2)/...
            (B+2*sqrt((depth(i,2))^2+(z*depth(i,2))^2));
        
        end
      
    end
    
%%%%%%%%% Compute the water velocity from full St.Venant Eq. (5.7) %%%%%%%%
    
    for i=2:sections
        
       if depth(i,2) < tol_depth
           
           velocity(i,2) = 0;
                
       else
            
		dummy = -velocity(i,1)*timestep*0.5/deltax...
            *(velocity(i+1,1)-velocity(i-1,1));
		dummy = dummy + -9.81*(timestep*0.5/deltax)*(depth(i+1,1)-...
            depth(i-1,1)); 
		dummy = dummy + 9.81*slope*timestep;
		dummy = dummy + - velocity(i,1)*velocity(i,1)*timestep*9.81...
            /(((R_hyd(i,1))^1.3333)*manning*manning);                  
		velocity(i,2) = velocity(i,1) + dummy;
        
        end
    end
    
%%%%%%%%%%%%% Correcting depth according to Eq. (6.8) %%%%%%%%%%%%%%%%%%%%%
    
    for i=2:sections
        
       if depth(i,2) < tol_depth
            
           depth(i,2) = tol_depth;
           velocity(i,2) = 0;
                
        else
               
		u = 0.5*(velocity(i,1)+velocity(i,2));          
		depth(i,2) = (0.5*(velocity(i-1,2)+velocity(i-1,1))*depth(i-1,2)+...
            depth(i,1)*(deltax/timestep-0.5*u))/...
            (deltax/timestep+0.5*u);
        
            if shape == 1
            
            R_hyd(i,2) = (B*depth(i,2))/(2*depth(i,2)+B);
        
            elseif shape == 2
            
            B_t(i,2) = B+2*z*depth(i,2);
            area_trap(i,2) = ((B+B_t(i,2))/2)*depth(i,2);
            R_hyd(i,2) = area_trap(i,2)/...
                (B+2*sqrt((depth(i,2))^2+(z*depth(i,2))^2));
        
            end
        
       end
        
        if shape == 1
            
            A(i,2) = depth(i,2)*B;          
            
        end
        
        if shape == 2
           
            B_t(i,2) = B+2*depth(i,2)*z;
            A(i,2) = ((B+B_t(i,2))/2)*depth(i,2);
            
        end
        
    end
    
%%%%%%%%%%%%%%%% Infiltration step solving Eq. (5.12) %%%%%%%%%%%%%%%%%%%%%
    
    if infiltration_step == 1               %Calculates infiltration in cm
            
        inf_length = inf_length+max(velocity(1:sections,2))*timestep;     
        
        if inf_length > length
            
            inf_length = length;
            
        end
        
        depth_avg = mean(depth(1:sections,2));  
        %Mean channel flow depth in current timestep
            
        if j == 1
            
            I(j) = I_0;
            
        else
            
            if I(j-1) < z_tot           
            %Infiltration only if wetting front has not reached matrix
            %depth.
                
            if solver == 1  %Symbolic solver
                
            syms I_solver
            
            old = digits;
            
            digits(10);     %Solver accuracy
            
            I_temp = vpasolve(K_sat*(time/(60*60))*cos(gamma)...
                +((psi+depth_avg*100*cos(gamma))*(theta_sat-theta_0))...
                /(cos(gamma))*log(1+(I_solver*cos(gamma)/...
                ((psi+depth_avg*cos(gamma))*(theta_sat-theta_0))))==...
                I_solver, I_solver, K_sat*(time/(60*60))*cos(gamma));
            
            double(I_temp);
            
            digits(old);
            
            elseif solver == 2  %Numerical solver
            
            for l = 2:3000                    
        
                inf_control(1) = K_sat*(time/(60*60))*cos(gamma);
                
                inf = K_sat*(time/(60*60))*cos(gamma)...
                    +((psi+depth_avg*100*cos(gamma))*(theta_sat-theta_0))... 
                    /(cos(gamma))*log(1+(inf_control(l-1)*cos(gamma)/...
                    ((psi+depth_avg*cos(gamma))*(theta_sat-theta_0))));
        
                if abs(inf-inf_control(l-1)) < 0.001
                    
                    I_temp = inf_control(l-1);
                    %disp(l);   counter to track number og necessary
                    %iterations
                    
                    break
                    
                else
                    
                    inf_control(l) = inf_control(l-1)+0.01;
                    
                end
        
            end
            
            end
            
                I(j) = I_temp;
                
                I_diff(j) = I(j)-I(j-1); 
                %Change in infiltrated amount [cm] per section per timestep
                
            else
                
                I(j) = z_tot;
                
                I_diff(j) = 0;
            
            end
            
        end
            
            if shape == 1       
                
                I_vol(j) = (I(j)/100)*inf_length*B;           
                %Cummulative infiltrated volume per section per timestep in
                %m^3
                
            end
            
            if shape == 2
                
                B_t_avg = mean(B_t(1:sections,1));
                I_vol(j) = (I(j)/100)*inf_length*B_t_avg;
                %Cummulative infiltrated volume per section per timestep in
                %m^3
                
            end
            
            
 %%%%%%%%%%%%%%%%%%%Reduce depth as a result of infiltration%%%%%%%%%%%%%%%
 
            
            for i = 2:sections
                    
                if I_diff(j) < 0.1
                    
                %Tolerance demand in order to disregard false oscillations
                %in Green Ampt
                
                depth(i,2) = depth(i,2)-abs(I_diff(j))/100;
                   
                if I_diff(j)/100 > depth(i,2)
                    
                    depth(i,2) = tol_depth;
                
                elseif depth(i,2) < tol_depth
                    
                    depth(i,2) = tol_depth;
                    
                end
                    
                end
            
            end
            
    end
        
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Updating variables
    
    for i = 2:sections
        
        if shape == 1
            
            area_rect(i,1) = area_rect(i,2);
        
        elseif shape == 2
            
            B_t(i,1) = B_t(i,2);
            area_trap(i,1) = area_trap(i,2);
            
        end
        
        velocity(i,1) = velocity(i,2);
        depth(i,1) = depth(i,2);
        R_hyd(i,1) = R_hyd(i,2);
        
    end
    
%%%%%%%%%%%%%%%%%%%%%%%%%% Check for instabilities %%%%%%%%%%%%%%%%%%%%%%%%

        Cr = (abs(u)+sqrt(9.81*y))/(deltax/timestep); 

            if Cr > 1
                
                disp('Break on iteration number: ');
                disp(j);
                disp('Courant number exceeded! Reduce timestep.');
    
                break    
                
            end
    
    time = time + timestep;         %Increasing timestep for entire loop        
            
   
    
    %disp(j);                       %Counter to track progress of main loop
    
%%%%%%%%%%%%%%%%%%%%%%%%%%% Printing to file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    tab_q(:,1)=time;
    tab_q(:,2)=velocity(2,2)*A(2,2);
    tab_q(:,3)=velocity((length/deltax)-1,2)*A((length/deltax)-1,2);
    dlmwrite('outflow.txt', tab_q, 'delimiter', ' ',...
        '-append', 'precision', '%.6f')
    
    tab_y(:,1) = time;
    tab_y(:,2) = depth(2,2);
    tab_y(:,3) = depth((length/deltax)-1,2);
    dlmwrite('depth.txt', tab_y, 'delimiter', ' ',...
        '-append', 'precision', '%.6f')
    
    tab_u(:,1) = time;
    tab_u(:,2) = velocity(2,2);
    tab_u(:,3) = velocity((length/deltax)-1,2);
    dlmwrite('velocity.txt', tab_u, 'delimiter',...
        ' ', '-append', 'precision', '%.6f')
    
    if infiltration_step == 1
    
    tab_inf(:,1) = time;
    tab_inf(:,2) = I_vol(j);
    tab_inf(:,3) = I(j);
    dlmwrite('infiltration.txt', tab_inf,...
        'delimiter', ' ', '-append', 'precision', '%.6f')
    
    end
   
    
end


%%%%%%%%%%%%%%%%%%%%%%% Plotting discharge %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

temp_q = load('outflow.txt');
a_q = temp_q(:,1);
b_q = temp_q(:,2);
c_q = temp_q(:,3);

if infiltration_step == 1
   
    temp_inf = load('infiltration.txt');
    a_inf = temp_inf(:,1);
    b_inf = temp_inf(:,2);
    
end

h_q = figure('Visible','off');

if infiltration_step == 1
    
[haxes,hline1,hline2] = plotyy(a_q, [b_q c_q], a_q, b_inf,'plot');
set(haxes(1), 'YLim', [0 max(b_q)])
set(haxes(1), 'YTick', 0:0.1:max(b_q))
set(haxes(2), 'YLim', [min(b_inf) max(b_inf)])
set(haxes(2), 'YTick', 0:5:max(b_inf))
set(haxes(1), 'Xlim', [0 max(a_q)])
set(haxes(2), 'XLim', [0 max(a_q)])
title('Discharge - Infiltration')
xlabel(haxes(2), 'Time[s]')
ylabel(haxes(1), 'm^3/s')
ylabel(haxes(2), 'm^3', 'Color', 'k')
set(hline1, 'LineStyle', '-', {'Color'}, {[0.6 0 0.5];[0.7 0.6 0]},...
    'LineWidth', 1.5)
set(hline2, 'LineStyle', '-.', 'Color', [0 0.5 0.6], 'Linewidth', 1.5)
set(haxes, {'ycolor'},{'k';'k'})
legend('Inflow','Outflow','Cumulative infiltration')
legend('Location', 'East')
figureHandle = gcf;
set(findall(figureHandle, 'type', 'text'), 'fontSize', 16)
set(gca, 'FontName', 'Helvetica')
set(gca,...
    'Box', 'off', 'Tickdir', 'out', 'TickLength', [.02 .02],...
    'XminorTick', 'on', 'YMinorTick', 'on', 'Ygrid', 'on')
set(haxes(2), 'XTick', [], 'XTicklab', [])


print(h_q,'-dpng', '-r125', [['Discharge - Infiltration, ','Timestep = ',...
    num2str(timestep), ', Cross Section = ', num2str(shape), ', S_0 = ',...
    num2str(slope), ', M = ', num2str(manning)], ', Soiltype = ',...
    num2str(soiltype), ', Initial Saturation = ', num2str(theta_0),...
    '.png'])

    
else
p = plot(a_q, b_q, '-', a_q, c_q, '-');                                         
axis([0 max(a_q) 0 max(b_q)])
title('Discharge')
xlabel('Time [s]')
ylabel('Discharge [m3/s]')
set(p, 'Linestyle', '-', {'Color'}, {[0.6 0 0.5];[0.7 0.6 0]},...
    'LineWidth', 1.5)
legend('Inflow', 'Outflow')
legend('Location', 'East')
set(gca, 'FontName', 'Helvetica')
figureHandle = gcf;
set(findall(figureHandle, 'type', 'text'), 'fontSize', 16)
set(gca,...
    'Box', 'off', 'Tickdir', 'out', 'TickLength', [.02 .02],...
    'XminorTick', 'on', 'YMinorTick', 'on', 'Ygrid', 'on')

print(h_q,'-dpng', '-r125', [['Discharge, ','Timestep = ',...
    num2str(timestep), ', Cross Section = ', num2str(shape), ', S_0 = ',...
    num2str(slope), ', M = ', num2str(manning)],'.png'])

end
close(h_q)

%%%%%%%%%%%%%%%%%%%%%%%%%%% Plotting depth %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

temp_y = load('depth.txt');
a_y = temp_y(:,1);
b_y = temp_y(:,2);
c_y = temp_y(:,3);
h_y = figure('Visible','off');

py = plot(a_y,[b_y c_y]);                                         
axis([0 max(a_y) 0 max(b_y)])
title('Depth')
xlabel('Time [s]')
ylabel('Depth [m]')
set(py, 'Linestyle', '-', {'Color'}, {[0.6 0 0.9];[0.2 0.6 0.5]},...
    'LineWidth', 1.5)
legend('Inflow', 'Outflow')
legend('Location', 'East')
figureHandle = gcf;
set(gca, 'FontName', 'Helvetica')
set(findall(figureHandle, 'type', 'text'), 'fontSize', 16)
set(gca,...
    'Box', 'off', 'Tickdir', 'out', 'TickLength', [.02 .02],...
    'XminorTick', 'on', 'YMinorTick', 'on', 'Ygrid', 'on')


if infiltration_step == 1
    
print(h_y,'-dpng', '-r125', [['Depth, ','Timestep = ',...
    num2str(timestep), ', Cross Section = ', num2str(shape), ', S_0 = ',...
    num2str(slope), ', M = ', num2str(manning)], ', Soiltype = ',...
    num2str(soiltype), ', Initial Saturation = ', num2str(theta_0),...
    '.png'])

else
    
print(h_y,'-dpng', '-r125', [['Depth, ','Timestep = ',...
    num2str(timestep), ', Cross Section = ', num2str(shape), ', S_0 = ',...
    num2str(slope), ', M = ', num2str(manning)],'.png'])
    
end

close(h_y)

%%%%%%%%%%%%%%%%%%%%%%%%%%% Plotting velocity %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

temp_u = load('velocity.txt');
a_u = temp_u(:,1);
b_u = temp_u(:,2);
c_u = temp_u(:,3);

h_u = figure('Visible','off');

pu = plot(a_u,[b_u c_u]);                                         
axis([0 max(a_u) 0 max(b_u)])
title('Velocity')
xlabel('Time [s]')
ylabel('Velocity [m/s]')
set(pu, 'Linestyle', '-', {'Color'}, {[0.3 0.7 0.2];[1 0.5 0.1]},...
    'LineWidth', 1.5)
legend('Inflow', 'Outflow')
legend('Location', 'East')
set(gca, 'FontName', 'Helvetica')
figureHandle = gcf;
set(findall(figureHandle, 'type', 'text'), 'fontSize', 16)
set(gca,...
    'Box', 'off', 'Tickdir', 'out', 'TickLength', [.02 .02],...
    'XminorTick', 'on', 'YMinorTick', 'on', 'Ygrid', 'on')

if infiltration_step == 1
    
print(h_u,'-dpng', '-r125', [['Velocity, ','Timestep = ',...
    num2str(timestep), ', Cross Section = ', num2str(shape), ', S_0 = ',...
    num2str(slope), ', M = ', num2str(manning)], ', Soiltype = ',...
    num2str(soiltype), ', Initial Saturation = ', num2str(theta_0),...
    '.png'])

else
    
print(h_u,'-dpng', '-r125', [['Velocity, ','Timestep = ',...
    num2str(timestep), ', Cross Section = ', num2str(shape), ', S_0 = ',...
    num2str(slope), ', M = ', num2str(manning)],'.png'])
    
end
close(h_u)

%%%%%%%%%%%%%%%%%%%%%% Plotting infiltration %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if infiltration_step == 1

temp_inf = load('infiltration.txt');
a_inf = temp_inf(:,1);
b_inf = temp_inf(:,2);
c_inf = temp_inf(:,3);

h_inf = figure('Visible','off');

[haxesi,hline1i,hline2i] = plotyy(a_inf, b_inf, a_inf, c_inf,'plot');
set(haxesi(1), 'YLim', [min(b_inf) max(b_inf)])
set(haxesi(1), 'YTick', 0:5:max(b_inf))
set(haxesi(2), 'YLim', [min(c_inf) max(c_inf)])
set(haxesi(2), 'YTick', 0:5:max(c_inf))
set(haxesi(1), 'Xlim', [0 max(a_inf)])
set(haxesi(2), 'Xlim', [0 max(a_inf)])
title({'Cumulative volumetric infiltration';...
    'Cumulative infiltration depth'})
xlabel(haxesi(2), 'Time[s]')
ylabel(haxesi(1), 'm^3')
ylabel(haxesi(2), 'cm', 'Color', 'k')
set(hline1i, 'LineStyle', '-.', 'Color', [0.6 0 0.5], 'LineWidth', 2)
set(hline2i, 'LineStyle', ':', 'Color', [0 0.5 0.6], 'Linewidth', 2)
set(haxesi, {'ycolor'},{'k';'k'})
legend('Cumulative volume', 'Cumulative depth')
legend('Location', 'East')
set(gca, 'FontName', 'Helvetica')
figureHandle = gcf;
set(findall(figureHandle, 'type', 'text'), 'fontSize', 16)
set(gca,...
    'Box', 'off', 'Tickdir', 'out', 'TickLength', [.02 .02],...
    'XminorTick', 'on', 'YMinorTick', 'on', 'Ygrid', 'on')
set(haxesi(2), 'XTick', [], 'XTicklab', [])


print(h_q,'-dpng', '-r125', [['Infiltration, ','Timestep = ',...
    num2str(timestep), ', Cross Section = ', num2str(shape), ', S_0 = ',...
    num2str(slope), ', M = ', num2str(manning)], ', Soiltype = ',...
    num2str(soiltype), ', Initial Saturation = ', num2str(theta_0),...
    '.png'])

close(h_inf)

end


disp('Finished!')
